# Machine Learning

::::{grid} 1 2 2 3
:margin: 4 4 0 0
:gutter: 1

:::{grid-item-card} {octicons}`git-merge-queue` Activation Functions
:link: activationFunctions
:link-type: doc

Activation functions for neural networks.
:::
::::

```{toctree}
:hidden:
:maxdepth: 3

Activation Functions <activationFunctions.md>
```
